Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/SymbSyntDec/SymbSyntDec.py | (no class) | 17 | 0 | 0 | 100%
src/SymbSyntDec/__init__.py | (no class) | 8 | 0 | 0 | 100%
src/SymbSyntDec/closure.py | (no class) | 32 | 0 | 0 | 100%
src/SymbSyntDec/ground.py | (no class) | 24 | 0 | 0 | 100%
src/SymbSyntDec/modify.py | (no class) | 36 | 0 | 0 | 100%
src/SymbSyntDec/past.py | (no class) | 5 | 0 | 0 | 100%
src/SymbSyntDec/pastSimple.py | (no class) | 7 | 0 | 0 | 100%
src/SymbSyntDec/snf.py | (no class) | 35 | 0 | 0 | 100%
src/SymbSyntDec/state_variables.py | (no class) | 31 | 0 | 0 | 100%
src/__init__.py | (no class) | 0 | 0 | 0 | 100%
tests/__init__.py | (no class) | 1 | 0 | 0 | 100%
tests/test_modify.py | TestModify | 76 | 0 | 0 | 100%
tests/test_modify.py | (no class) | 50 | 10 | 0 | 80%
Total |  | 322 | 10 | 0 | 97%

No items found using the specified filter.